@@ -1,6 +1,4 @@
 package KinoSearch::Index::NormsReader;
-use strict;
-use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
@@ -8,7 +6,8 @@ our %instance_vars = __PACKAGE__->init_instance_vars(
     # constructor params / members
     instream => undef,
     max_doc  => undef,
-    bytes    => undef,
+    # members
+    bytes => undef,
 );
 
 sub init_instance {
@@ -62,7 +61,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.10.
+See L<KinoSearch|KinoSearch> version 0.05.
 
 =end devdocs
 =cut
