@@ -1,11 +1,9 @@
 package KinoSearch::Index::TermBuffer;
-use strict;
-use warnings;
 use KinoSearch::Util::ToolSet;
-use base qw( KinoSearch::Util::CClass );
+use base qw( KinoSearch::Util::Class );
 
 our %instance_vars = __PACKAGE__->init_instance_vars(
-    # constructor params
+    # constructor args
     finfos => undef,
 );
 
@@ -14,7 +12,7 @@ sub new {
     $class = ref($class) || $class;
     my %args = ( %instance_vars, @_ );
     verify_args( \%instance_vars, %args );
-    my $self = _new( $class, $args{finfos}->size );
+    my $self = _new( $class, $args{finfos}, $args{finfos}->get_fnum_map );
     return $self;
 }
 
@@ -27,17 +25,33 @@ __XS__
 MODULE = KinoSearch    PACKAGE = KinoSearch::Index::TermBuffer
 
 void
-_new(class, finfos_size) 
-    char *class;
-    I32   finfos_size;
+_new(class, finfos_sv, fnum_map_sv) 
+    char       *class;
+    SV         *finfos_sv;
+    SV         *fnum_map_sv;
 PREINIT:
     TermBuffer *term_buf;
+    char       *ptr;
+    STRLEN      len;
 PPCODE:
-    term_buf = Kino_TermBuf_new(finfos_size);
-    ST(0)   = sv_newmortal();
+{
+    Kino_New(0, term_buf, 1, TermBuffer);
+    SvREFCNT_inc(finfos_sv);
+    term_buf->finfos = finfos_sv;
+
+    /* reset the TermBuffer */
+    term_buf->termstring = NULL;
+    Kino_TermBuf_reset(term_buf);
+
+    /* copy the fnum_map, derive max_field_num */
+    ptr                     = SvPV(fnum_map_sv, len);
+    term_buf->fnum_map      = Kino_savepvn(ptr, len);
+    term_buf->max_field_num = (len / KINO_FIELD_NUM_LEN) - 1;
+    
+    ST(0) = sv_newmortal();
     sv_setref_pv(ST(0), class, (void*)term_buf);
     XSRETURN(1);
-    
+}
 
 void
 DESTROY(term_buf)
@@ -45,6 +59,16 @@ DESTROY(term_buf)
 PPCODE:
     Kino_TermBuf_destroy(term_buf);
 
+
+void
+_set_text_len(term_buf, new_len)
+    TermBuffer *term_buf;
+    UV          new_len;
+PPCODE:
+    Kino_TermBuf_set_text_len(term_buf, new_len);
+    
+
+
 __H__
 
 #ifndef H_KINOSEARCH_INDEX_TERM_BUFFER
@@ -53,23 +77,22 @@ __H__
 #include "EXTERN.h"
 #include "perl.h"
 #include "XSUB.h"
-#include "KinoSearchIndexTerm.h"
-#include "KinoSearchStoreInStream.h"
-#include "KinoSearchUtilByteBuf.h"
-#include "KinoSearchUtilCarp.h"
 #include "KinoSearchUtilMemManager.h"
+#include "KinoSearchIndexTerm.h"
 
 typedef struct termbuffer {
-    ByteBuf *termstring;
-    I32      text_len;
-    I32      max_field_num;
+    SV      *finfos;
+    char    *termstring;
+    STRLEN   text_len;
+    STRLEN   capacity;
+    char    *fnum_map;
+    U32      max_field_num;
 } TermBuffer;
 
-TermBuffer* Kino_TermBuf_new(I32);
-void Kino_TermBuf_read(TermBuffer*, InStream*);
-void Kino_TermBuf_reset(TermBuffer*);
-void Kino_TermBuf_set_termstring(TermBuffer*, char*, I32);
+void Kino_TermBuf_read(TermBuffer*, PerlIO*);
 void Kino_TermBuf_destroy(TermBuffer*);
+void Kino_TermBuf_reset(TermBuffer*);
+void Kino_TermBuf_set_text_len(TermBuffer*, STRLEN);
 
 #endif /* include guard */
 
@@ -77,47 +100,40 @@ __C__
 
 #include "KinoSearchIndexTermBuffer.h"
 
-static void Kino_TermBuf_set_text_len(TermBuffer*, I32);
-
-TermBuffer*
-Kino_TermBuf_new(I32 finfos_size) {
-    TermBuffer *term_buf;
-
-    /* allocate */
-    Kino_New(0, term_buf, 1, TermBuffer);
-
-    /* reset the TermBuffer */
-    term_buf->termstring = NULL;
-    Kino_TermBuf_reset(term_buf);
-
-    /* derive max_field_num */
-    term_buf->max_field_num = finfos_size - 1;
-
-    return term_buf;
-}
-
 /* Decode the next term in a term dictionary file (.tii, .tis), but don't turn
  * it into a full-fledged Term object. */
 void
-Kino_TermBuf_read(TermBuffer *term_buf, InStream *instream) {
-    I32 text_overlap, finish_chars_len, total_text_len, field_num;
+Kino_TermBuf_read(TermBuffer *term_buf, PerlIO *fh) {
+    I32 text_overlap;
+    STRLEN finish_chars_len;
+    STRLEN total_text_len;
+    U32 field_num;
 
     /* read bytes which are shared between the last term text and this */
-    text_overlap     = instream->read_vint(instream);
-    finish_chars_len = instream->read_vint(instream);
+    text_overlap     = Kino_IO_read_vint(fh);
+    finish_chars_len = Kino_IO_read_vint(fh);
     total_text_len   = text_overlap + finish_chars_len;
     Kino_TermBuf_set_text_len(term_buf, total_text_len);
-    instream->read_chars(instream, term_buf->termstring->ptr, 
+    Kino_IO_read_chars(fh, term_buf->termstring, 
         (text_overlap + KINO_FIELD_NUM_LEN),
         finish_chars_len);
 
-    /* read field num */
-    field_num = instream->read_vint(instream);
+    /* read orig field num -- not the same as the final; see FieldInfos */
+    field_num = Kino_IO_read_vint(fh);
     if (field_num > term_buf->max_field_num && field_num != -1)
         Kino_confess("Internal error: field_num %d > max_field_num %d",
             field_num, term_buf->max_field_num);
 
-    Kino_encode_bigend_U16( (U16)field_num, term_buf->termstring->ptr);
+    if (field_num == -1) {
+        term_buf->termstring[0] = 0xff;     
+        term_buf->termstring[1] = 0xff;
+    }
+    /* assign the KinoSearch-compatible field num from the map */
+    else {
+        Copy( (term_buf->fnum_map + 2*field_num), 
+               term_buf->termstring, 2, char);
+    }
+
 }
 
 /* Set the TermBuffer object to a sentinel state, indicating that it does not
@@ -125,46 +141,44 @@ Kino_TermBuf_read(TermBuffer *term_buf, InStream *instream) {
 void
 Kino_TermBuf_reset(TermBuffer *term_buf) {
     if (term_buf->termstring != NULL) {
-        Kino_BB_destroy(term_buf->termstring);
-        term_buf->termstring = NULL;
+        Kino_Safefree(term_buf->termstring);
     }
+    term_buf->termstring = NULL;
     term_buf->text_len   = 0;
-}
-
-void
-Kino_TermBuf_set_termstring(TermBuffer *term_buf, char* ptr, I32 len) {
-    /* the passed in len includes the length of the encoded field num */
-    if (len < 2)
-        Kino_confess("can't set_termstring with a len < 2: %d", len);
-    Kino_TermBuf_set_text_len(term_buf, len - KINO_FIELD_NUM_LEN);
-
-    Kino_BB_assign_string(term_buf->termstring, ptr, len);
+    term_buf->capacity   = 0;
 }
 
 /* Set the length of the term text, and ensure that there's enough memory
  * allocated to hold term text that size. */
-static void 
-Kino_TermBuf_set_text_len(TermBuffer *term_buf, I32 new_len) {
-    ByteBuf* termstring = term_buf->termstring;
-
-    /* initialize if necessary, with a field number of 0 */
-    if (termstring == NULL) {
-        termstring = Kino_BB_new_string("\0\0", 2);
-        term_buf->termstring = termstring;
-    }
-
-    /* realloc and set lengths */
-    Kino_BB_grow(termstring, new_len + KINO_FIELD_NUM_LEN);
-    termstring->size   = new_len + KINO_FIELD_NUM_LEN;
+void 
+Kino_TermBuf_set_text_len(TermBuffer *term_buf, STRLEN new_len) {
     term_buf->text_len = new_len;
+    
+    /* bail if the buffer's already at least as big as required */
+    if (term_buf->capacity >= new_len + KINO_FIELD_NUM_LEN) {
+        return;
+    }
+    else {
+        STRLEN amount_to_malloc;
 
-    /* null-terminate */
-    termstring->ptr[ termstring->size ] = '\0';
+        term_buf->capacity = new_len + KINO_FIELD_NUM_LEN;
+        amount_to_malloc   = term_buf->capacity + 1;
+        if (term_buf->termstring == NULL) {
+            Kino_New(0, term_buf->termstring, amount_to_malloc, char);
+            Copy("\0\0", term_buf->termstring, 2, char);
+        }
+        else {
+            Kino_Renew(term_buf->termstring, amount_to_malloc, char);
+        }
+        term_buf->termstring[ term_buf->capacity ] = '\0';
+    }
 }
 
 void 
 Kino_TermBuf_destroy(TermBuffer *term_buf) {
     Kino_TermBuf_reset(term_buf);
+    Kino_Safefree(term_buf->fnum_map);
+    SvREFCNT_dec(term_buf->finfos);
     Kino_Safefree(term_buf);
 }
 
@@ -188,7 +202,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.10.
+See L<KinoSearch|KinoSearch> version 0.05.
 
 =end devdocs
 =cut
