@@ -1,8 +1,6 @@
 package KinoSearch::Index::TermEnum;
-use strict;
-use warnings;
 use KinoSearch::Util::ToolSet;
-use base qw( KinoSearch::Util::CClass );
+use base qw( KinoSearch::Util::Class );
 
 our %instance_vars = __PACKAGE__->init_instance_vars();
 
@@ -87,7 +85,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.10.
+See L<KinoSearch|KinoSearch> version 0.05.
 
 =end devdocs
 =cut
