@@ -1,6 +1,4 @@
 package KinoSearch::Index::TermInfosReader;
-use strict;
-use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
@@ -36,15 +34,12 @@ sub init_instance {
     $self->{index_enum}->fill_cache;
 }
 
-# Return a SegTermEnum, pre-located at the right spot if a Term is supplied.
+# Given a term, return a SegTermEnum pre-located at the right spot.
 sub terms {
     my ( $self, $term ) = @_;
-    if ( defined $term ) {
-        $self->fetch_term_info($term);
-    }
-    else {
-        $self->{orig_enum}->reset;
-    }
+
+    # seek to the right place and return a clone of the main Enum
+    $self->fetch_term_info($term);
     return $self->{orig_enum}->clone_enum;
 }
 
@@ -128,7 +123,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.10.
+See L<KinoSearch|KinoSearch> version 0.05.
 
 =end devdocs
 =cut
