@@ -1,12 +1,8 @@
-use strict;
-use warnings;
-
 package KinoSearch::Search::BooleanClause;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
-our %instance_vars = (
-    # params / members
+our %instance_vars = __PACKAGE__->init_instance_vars(
     occur => 'SHOULD',
     query => undef,
 );
@@ -14,7 +10,7 @@ our %instance_vars = (
 sub init_instance {
     my $self = shift;
 
-    confess("invalid value for 'occur': '$self->{occur}'")
+    croak("invalid value for 'occur': '$self->{occur}'")
         unless $self->{occur} =~ /^(?:MUST|MUST_NOT|SHOULD)$/;
 }
 
@@ -42,9 +38,9 @@ __END__
 
 =begin devdocs
 
-=head1 PRIVATE CLASS
+=head1 NAME
 
-KinoSearch::Search::BooleanClause - Clause in a BooleanQuery.
+KinoSearch::Search::BooleanClause - clause in a BooleanQuery
 
 =head1 DESCRIPTION 
 
@@ -52,11 +48,11 @@ A clause in a BooleanQuery.
 
 =head1 COPYRIGHT
 
-Copyright 2005-2007 Marvin Humphrey
+Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch> version 0.20.
+See L<KinoSearch|KinoSearch> version 0.05.
 
 =end devdocs
 =cut
