@@ -1,6 +1,4 @@
 package KinoSearch::Search::HitDoc;
-use strict;
-use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
@@ -20,7 +18,7 @@ __END__
 
 =head1 NAME
 
-KinoSearch::Search::HitDoc - successful match for a Query
+KinoSearch::Search::HitDoc - document which matched a Query
 
 =head1 DESCRIPTION 
 
@@ -32,9 +30,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.10.
+See L<KinoSearch|KinoSearch> version 0.05.
 
 =end devdocs
-
 =cut
-
