@@ -1,6 +1,4 @@
 package KinoSearch::Store::RAMLock;
-use strict;
-use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Store::Lock );
 
@@ -50,7 +48,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.10.
+See L<KinoSearch|KinoSearch> version 0.05.
 
 =end devdocs
 =cut
