@@ -1,6 +1,3 @@
-use strict;
-use warnings;
-
 package KinoSearch::Util::ToStringUtils;
 use KinoSearch::Util::ToolSet;
 use base qw( Exporter );
@@ -19,9 +16,9 @@ __END__
 
 =begin devdocs
 
-=head1 PRIVATE CLASS
+=head1 NAME
 
-KinoSearch::Util::ToStringUtils - Common routines which aid stringification.
+KinoSearch::Util::ToStringUtils - common routines which aid stringification
 
 =head1 DESCRIPTION
 
@@ -29,11 +26,11 @@ Provide functions which help with to_string.
 
 =head1 COPYRIGHT
 
-Copyright 2005-2007 Marvin Humphrey
+Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch> version 0.20.
+See L<KinoSearch|KinoSearch> version 0.05.
 
 =end devdocs
 =cut
