@@ -1,18 +1,13 @@
+package KinoSearch::Util::VerifyArgs;
 use strict;
 use warnings;
 
-package KinoSearch::Util::VerifyArgs;
-
 use Scalar::Util qw( blessed );
 use Carp;
 
 use base qw( Exporter );
 
-our @EXPORT_OK = qw( verify_args kerror a_isa_b );
-
-my $kerror;
-
-sub kerror {$kerror}
+our @EXPORT_OK = qw( verify_args a_isa_b );
 
 # Verify that named parameters exist in a defaults hash.
 sub verify_args {
@@ -21,9 +16,7 @@ sub verify_args {
     # verify that args came in pairs
     if ( @_ % 2 ) {
         my ( $package, $filename, $line ) = caller(1);
-        $kerror
-            = "Parameter error: odd number of args at $filename line $line\n";
-        return 0;
+        die "Parameter error: odd number of args at $filename line $line\n";
     }
 
     # verify keys, ignore values
@@ -31,11 +24,8 @@ sub verify_args {
         my ( $var, undef ) = ( shift, shift );
         next if exists $defaults->{$var};
         my ( $package, $filename, $line ) = caller(1);
-        $kerror = "Invalid parameter: '$var' at $filename line $line\n";
-        return 0;
+        die "Invalid parameter: '$var' at $filename line $line\n";
     }
-
-    return 1;
 }
 
 =begin comment
@@ -59,13 +49,11 @@ sub a_isa_b {
 
 __END__
 
-__POD__
-
 =begin devdocs
 
-=head1 PRIVATE CLASS
+=head1 NAME
 
-KinoSearch::Util::VerifyArgs - Some validation functions.
+KinoSearch::Util::VerifyArgs - some validation functions
 
 =head1 DESCRIPTION
 
@@ -73,11 +61,11 @@ Provide some utility functions under the general heading of "verification".
 
 =head1 COPYRIGHT
 
-Copyright 2005-2007 Marvin Humphrey
+Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS etc.
 
-See L<KinoSearch> version 0.20.
+See L<KinoSearch|KinoSearch> version 0.05.
 
 =end devdocs
 =cut
